Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become...
Date: 2016-10-11

# You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov

# Cryptographic Module Validation Program CMVP

### Modules In Process List

The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become available. The validation process is a joint effort between the CMVP, the laboratory and the vendor and therefore, for any given module, the action to respond could reside with the CMVP, the lab or the vendor. This list does not provide granularity into which entity has the action. If you would like more information for a specific cryptographic module or its schedule, please contact the vendor.

Last Updated: 10/23/2020

Module Name | Vendor Name | Standard | Review Pending | In Review | Coordination | Finalization
--- | --- | --- | --- | --- | --- | ---
Thunder Series TH-3040S, TH-5440S, TH-5840S and TH-7440S-11 | A10 Networks, Inc. | FIPS 140-2 |  |  |  |
Acronis SCS Cryptographic Module | Acronis SCS | FIPS 140-2 |  |  |  |
ADVA 10TCE-PCN-16GU+AES100G-F encryption module | ADVA Optical Networking SE | FIPS 140-2 |  |  |  |
ADVA 9TCE-PCN-10GU+AES10G-F encryption module | ADVA Optical Networking SE | FIPS 140-2 |  |  |  |
WCC-PCN-AES100GB-F Encryption Module | ADVA Optical Networking SE | FIPS 140-2 |  |  |  |
Advantech SQFlash FIPS Certified SSD | Advantech Co., Ltd. | FIPS 140-2 |  |  |  |
SBx908 GEN2, AT-x950-28XTQm, AT-x550-18XTQ, AT-x550-18XSQ, AT-x550-18XSPQm, and AT-x530-28GTXm Secure Management Module | Allied Telesis | FIPS 140-2 |  |  |  |
AWS Nitro Card Security Engine | Amazon Web Services, Inc. | FIPS 140-2 |  |  |  |
Apple CoreCrypto Kernel Space Module for ARM | Apple Inc. | FIPS 140-2 |  |  |  |
Apple CoreCrypto Kernel Space Module for Intel | Apple Inc. | FIPS 140-2 |  |  |  |
Apple CoreCrypto User Space Module for ARM | Apple Inc. | FIPS 140-2 |  |  |  |
Apple CoreCrypto User Space Module for Intel | Apple Inc. | FIPS 140-2 |  |  |  |
Apple Secure Key Store Cryptographic Module, 10.0 | Apple Inc. | FIPS 140-2 |  |  |  |
Aegis Fortress L3 Cryptographic Module | Apricorn | FIPS 140-2 |  |  |  |
Aegis Secure Key 3NX Cryptographic Module | Apricorn | FIPS 140-2 |  |  |  |
Arista EOS Crypto Module | Arista Networks, Inc. | FIPS 140-2 |  |  |  |
Aruba 9004 Series Gateway with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 |  |  |  |
Aruba AP-504, AP-505, AP-514, AP-515, AP-534, AP-535 and AP-555 Wireless Access Points with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 |  |  |  |
Aruba IAP-303H, IAP-304, IAP-305, IAP-314, IAP-315, IAP-324, IAP-325, IAP-334, and IAP-335 Wireless Access Points with Aruba Instant Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 |  |  |  |
Aruba Mobility Controller Virtual Appliances with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 |  |  |  |
Aruba Virtual and Hardware Mobility Master Appliances with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 |  |  |  |
TASS Crypto Engine | Beijing JN TASS Technology Co., Ltd. | FIPS 140-2 |  |  |  |
BCM58200 Series: BCM58201, BCM58202 | Broadcom, Inc. | FIPS 140-2 |  |  |  |
Ubuntu 18.04 Kernel Crypto API Cryptographic Module | Canonical Ltd. | FIPS 140-2 |  |  |  |
Ubuntu 18.04 Libgcrypt Cryptographic Module | Canonical Ltd. | FIPS 140-2 |  |  |  |
Ubuntu 20.04 Kernel Crypto API Cryptographic Module | Canonical Ltd. | FIPS 140-2 |  |  |  |
Ubuntu 20.04 Libgcrypt Cryptographic Module | Canonical Ltd. | FIPS 140-2 |  |  |  |
Ubuntu 20.04 OpenSSL Cryptographic Module | Canonical Ltd. | FIPS 140-2 |  |  |  |
Cisco Adaptive Security Appliance (ASA) Virtual | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ASA and ISA Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ASA and ISA Firepower Threat Defense Cryptographic Modules | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ASA Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ASR 1000 Series Routers with MACSEC | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ASR 1000 Series Routers without MACSEC | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9200 Series Switches | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9200L Series Switches | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9300 Series Switches | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9400 Series Switches | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9600 Series Switches | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9800 (40/80/L) Wireless Controllers running IOS-XE 16.12 | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Catalyst 9800-CL Wireless Controller IOS-XE 16.12 | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco FIPS Object Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Firepower 2100 Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Firepower 4100 and Cisco Firepower 9300 Series | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Firepower Next-Generation IPS Virtual (NGIPSv) Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Firepower Threat Defense on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Firepower Threat Defense Virtual (FTDv) Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco FTD FX-OS on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ISR 1000 Series Routers without MACSEC | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco ISR 4000 Series Routers with MACSEC | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Network Convergence System 1001 Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Cisco Network Convergence System 1004 Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 |  |  |  |
Citrix ADC MPX | Citrix Systems, Inc. | FIPS 140-2 |  |  |  |
FSM-2 Flash Storage Cryptographic Module | Curtiss-Wright Controls Defense Solutions | FIPS 140-2 |  |  |  |
DL4FE | DataLocker Inc. | FIPS 140-2 |  |  |  |
VNX 6 Gb/s SAS I/O Module with Encryption | Dell EMC | FIPS 140-2 |  |  |  |
DIGISTOR TCG OPAL SSC FIPS SSD Series | DIGISTOR | FIPS 140-2 |  |  |  |
DocuSign HSM Appliance | DocuSign, Inc. | FIPS 140-2 |  |  |  |
DocuSign Signature Appliance | DocuSign, Inc. | FIPS 140-2 |  |  |  |
SOLSDR NETNode Security Module | Domo Tactical Communications (DTC) LTD | FIPS 140-2 |  |  |  |
DRAEGER WCM9113 802.11ABGN VG2 | Draeger Medical Systems, Inc. | FIPS 140-2 |  |  |  |
ECI TM200EN Encryption Module | ECI Telecom Ltd. | FIPS 140-2 |  |  |  |
Johnson Encryption Machine 2 (JEM2) | EF Johnson Technologies | FIPS 140-2 |  |  |  |
Entrust Authority™ Security Kernel | Entrust Datacard Corporation | FIPS 140-2 |  |  |  |
Envieta QFlex Hardware Security Module | Envieta Systems LLC | FIPS 140-2 |  |  |  |
Extreme Networks SLX 9640, SLX 9150 and SLX 9250 Switches | Extreme Networks, Inc. | FIPS 140-2 |  |  |  |
Extreme® MLXe® Series Ethernet Routers | Extreme Networks, Inc. | FIPS 140-2 |  |  |  |
Extreme® NetIron® CER 2000 Series Ethernet Routers | Extreme Networks, Inc. | FIPS 140-2 |  |  |  |
F5(R) Device Cryptographic Module | F5 Networks, Inc | FIPS 140-2 |  |  |  |
FEITIAN Biometric FIDO Key Module | FEITIAN Technologies | FIPS 140-2 |  |  |  |
OTP Token | FEITIAN Technologies | FIPS 140-2 |  |  |  |
FAST C-LIB | Fescaro Co. Ltd. | FIPS 140-2 |  |  |  |
FireEye CM Series: CM1500V, CM2500V, CM7500V | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye CM Series: CM4500, CM7500, CM9400, CM9500 | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye EX Series: EX3500, EX5500, EX8400, EX8500 | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye EX Series: EX5500V | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye HX Series: HX4402, HX4502, HX4502D | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye HX Series: HX4502V | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye NX Series: NX1500, NX2500, NX2550, NX3500, NX4500, NX5500, NX6500 | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye NX Series: NX1500V, NX2500V, NX2550V, NX4500V, NX6500V | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye VX Series: VX5500, VX12500, VX12550 | FireEye, Inc. | FIPS 140-2 |  |  |  |
FireEye VX Series: VX7690Vfips | FireEye, Inc. | FIPS 140-2 |  |  |  |
MonocryptAES Enhanced Crypto Library | Focus Systems Corporation | FIPS 140-2 |  |  |  |
Fornetix® Key Orchestration(tm) | Fornetix LLC | FIPS 140-2 |  |  |  |
Fortanix SDKMS Appliance | Fortanix, Inc. | FIPS 140-2 |  |  |  |
Fortanix SDKMS Appliance (FX2200, Version 3.10.16) | Fortanix, Inc. | FIPS 140-2 |  |  |  |
FortiAP-U221EV, FortiAP-U223EV, FortiAP-U321EV, FortiAP-U323EV, FortiAP-U421EV, FortiAP-U422EV, FortiAP-U423EV, FortiAP-U431F and FortiAP-U433F | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-1101E/2000E/2201E/2500E/3301E | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-201E/301E/401E/501E/601E | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-3401E/3601E/3960E/3980E | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-5001E1 Blade with FortiGate-5144C Chassis | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-61E/61F/81E/101E/101F and FortiWiFi-61E | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-6300F/6301F/6500F/6501F | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiGate-VM | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiOS 6.0 and 6.2 | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiWLC-50D/500D/1000D/3000D | Fortinet, Inc. | FIPS 140-2 |  |  |  |
FortiWLM-100D and FortiWLM-1000D | Fortinet, Inc. | FIPS 140-2 |  |  |  |
NRevenector 2018 | FP InovoLabs GmbH | FIPS 140-2 |  |  |  |
Postal NRevenector GB 2019 | FP InovoLabs GmbH | FIPS 140-2 |  |  |  |
1FINITY T600(TM) Transport Blade | Fujitsu Network Communications, Inc. | FIPS 140-2 |  |  |  |
Standalone IMB | GDC Technology (USA) LLC | FIPS 140-2 |  |  |  |
Fortress Mesh Points | General Dynamics Mission Systems | FIPS 140-2 |  |  |  |
GigaVUE-HC2 Visibility Appliance | Gigamon Inc. | FIPS 140-2 |  |  |  |
GigaVUE-HC3 Visibility Appliance | Gigamon Inc. | FIPS 140-2 |  |  |  |
BoringCrypto Android | Google, Inc. | FIPS 140-2 |  |  |  |
Titan Security Key, Chip Boundary | Google, LLC. | FIPS 140-2 |  |  |  |
Aruba 2930F, 2930M, 3810M and 5400R zl2 Switch Series | Hewlett Packard Enterprise | FIPS 140-2 |  |  |  |
HPE XP8 Encrypt Backend 4pk NVMe I/O Mod (eDKBN) | Hewlett Packard Enterprise Company | FIPS 140-2 |  |  |  |
HID Global Applets v3.0 on NXP JCOP 3 SecID P60 CS (OSB) | HID Global | FIPS 140-2 |  |  |  |
HID Global Applets v3.0 on NXP JCOP 3 SecID P60 CS (OSB) | HID Global | FIPS 140-2 |  |  |  |
Hitachi Virtual Storage Platform (VSP) Encryption Board for NVMe | Hitachi, Ltd. | FIPS 140-2 |  |  |  |
Hitachi Virtual Storage Platform (VSP) Encryption Module for NVMe | Hitachi, Ltd. | FIPS 140-2 |  |  |  |
HUAWEI OptiX OSN 1800 Series | Huawei Technologies Co., Ltd. | FIPS 140-2 |  |  |  |
IBM 4769 Cryptographic Coprocessor Security Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) z/OS(R) Version 2 Release 4 ICSF PKCS #11 Cryptographic Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) z/OS(R) Version 2 Release 4 ICSF PKCS #11 Cryptographic Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) z/OS(R) Version 2 Release 4 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) z/OS(R) Version 2 Release 4 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) z/VM(R) Version 7 Release 2 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 |  |  |  |
IBM(R) NVMe FlashCore(TM) Module 2 | IBM(R) Corporation | FIPS 140-2 |  |  |  |
LifeCare PCA™ Infusion Pump | ICU Medical, Inc. | FIPS 140-2 |  |  |  |
Trusted Platform Module 2.0 SLI / SLM 9670 | Infineon Technologies AG | FIPS 140-2 |  |  |  |
mTera Universal Transport Platform | Infinera Corporation | FIPS 140-2 |  |  |  |
Integral AES 256 Bit Crypto SSD Underlying PCB | Integral Memory Plc | FIPS 140-2 |  |  |  |
Integral Crypto AES 256 Bit USB 3.0 | Integral Memory Plc | FIPS 140-2 |  |  |  |
Cryptographic Module for Intel(R) Converged Security and Manageability Engine(CSME) | Intel Corporation | FIPS 140-2 |  |  |  |
Cryptographic Module for Intel® Platforms' Security Engine Chipset | Intel Corporation | FIPS 140-2 |  |  |  |
Cryptographic Module for Intel® Platforms' Security Engine Chipset | Intel Corporation | FIPS 140-2 |  |  |  |
iStorage datAshur BT | iStorage Ltd. | FIPS 140-2 |  |  |  |
iStorage datAshur PRO2 Level 3 Secure Storage Drive | iStorage Ltd. | FIPS 140-2 |  |  |  |
Juniper Networks EX4650, QFX5120 and QFX5210 Ethernet Switches | Juniper Networks, Inc | FIPS 140-2 |  |  |  |
Juniper Networks SRX300, SRX320, SRX340, SRX345, SRX345-DUAL-AC, SRX550M, SRX5400, SRX5600 and SRX5800 Services Gateways | Juniper Networks, Inc | FIPS 140-2 |  |  |  |
Juniper Networks SRX345, SRX345-DUAL-AC, SRX380 and SRX1500 Services Gateway | Juniper Networks, Inc | FIPS 140-2 |  |  |  |
Juniper Networks EX2300, EX2300-C and EX3400 Ethernet Switches | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks EX4300-48MP Ethernet Switch | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX10003 3D Universal Edge Router with JNP-MIC1-MACSEC MACSec MIC and EX9253 Ethernet Switch with EX9253-6Q12C-M MACSec Line Card | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX104 3D Universal Edge Router with the Multiservices MIC | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers and EX9204, EX9208, EX9214 Ethernet Switches with RE-S-X6-64G/RE-S-X6-128G/EX9200-RE2 Routing Engine and MPC7E-10G/EX9200-40XS MACsec Card | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE1800 Routing Engine and MPC7E-10G MACsec Card | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE1800 Routing Engine and Multiservices MPC | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE-S-X6-64G Routing Engine and Multiservices MPC | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Juniper Networks NFX250 Network Services Platform | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Junos Space Network Management Platform, Network Director & Security Director in JA2500 | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
Junos Space Network Management Platform, Network Director & Security Director in Virtual Appliance | Juniper Networks, Inc. | FIPS 140-2 |  |  |  |
KIOXIA TCG Enterprise SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation | FIPS 140-2 |  |  |  |
KIOXIA TCG OPAL SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation | FIPS 140-2 |  |  |  |
Laird Linux FIPS Core Crypto Module | Laird Connectivity | FIPS 140-2 |  |  |  |
ESCRYPT's CycurLIB | Landis+Gyr | FIPS 140-2 |  |  |  |
NITROXIII CNN35XX-NFBE HSM Family | Marvell | FIPS 140-2 |  |  |  |
AEDS | Maxar Technologies | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS3100, NS3200, NS5100 and NS5200 | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS3500 | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS7100, NS7200 and NS7300 | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS7150, NS7250 and NS7350 | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS9100 and NS9200 | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS9300 S | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS9300P | McAfee, LLC | FIPS 140-2 |  |  |  |
Network Security Platform Sensor NS9500 | McAfee, LLC | FIPS 140-2 |  |  |  |
Memkor MKD-O2F 2.5"/M.2/U.2 SSD | Memkor, Inc. | FIPS 140-2 |  |  |  |
Boot Manager | Microsoft Corporation | FIPS 140-2 |  |  |  |
Windows OS Loader | Microsoft Corporation | FIPS 140-2 |  |  |  |
FIPS AP43 | Mist Systems | FIPS 140-2 |  |  |  |
µMACE | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 2 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 2 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 3 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 3 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Key Variable Loader (KVL) 4000 PIKE2 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Key Variable Loader (KVL) 5000 PIKE2 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Motorola GGM 8000 Gateway | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Motorola Network Router (MNR) S6000 | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-2 |  |  |  |
nShield Solo XC F2 | nCipher Security Limited | FIPS 140-2 |  |  |  |
nShield Solo XC F3 and nShield Solo XC F3 for nShield Connect XC and for nShield Issuance HSM | nCipher Security Limited | FIPS 140-2 |  |  |  |
nShield Solo XC F3 and nShield Solo XC F3 for nShield Connect XC and for nShield Issuance HSM | nCipher Security Limited | FIPS 140-2 |  |  |  |
Nokia 1830 Photonic Service Switch (PSS) | Nokia Corporation | FIPS 140-2 |  |  |  |
NS361/NS371/NS561 (2.5" & M.2) SSD | Novachips Co., Ltd. | FIPS 140-2 |  |  |  |
NPCT7xx TPM 2.0 rev 1.38 | Nuvoton Technology Corporation | FIPS 140-2 |  |  |  |
FIPS SE051 | NXP Semiconductors | FIPS 140-2 |  |  |  |
i.MX 8X SECO HSM | NXP Semiconductors | FIPS 140-2 |  |  |  |
JCOP4 P71 | NXP Semiconductors | FIPS 140-2 |  |  |  |
SE050 | NXP Semiconductors | FIPS 140-2 |  |  |  |
Acme Packet 4600 and Acme Packet 6300 and Acme Packet 6350 | Oracle Communications | FIPS 140-2 |  |  |  |
Oracle Linux 7 GnuTLS Cryptographic Module | Oracle Corporation | FIPS 140-2 |  |  |  |
Oracle Linux Unbreakable Enterprise Kernel (UEK 5) Cryptographic Module | Oracle Corporation | FIPS 140-2 |  |  |  |
Oracle Linux Unbreakable Enterprise Kernel (UEK) Cryptographic Module | Oracle Corporation | FIPS 140-2 |  |  |  |
GlobalProtect App | Palo Alto Networks | FIPS 140-2 |  |  |  |
Palo Alto Networks Cortex XSOAR Module | Palo Alto Networks | FIPS 140-2 |  |  |  |
Panorama 9.0 M-100, M-200, M-500 and M-600 | Palo Alto Networks, Inc. | FIPS 140-2 |  |  |  |
Panorama Virtual Appliance 9.0 | Palo Alto Networks, Inc. | FIPS 140-2 |  |  |  |
PAN-OS 9.0 Firewalls PA-220, PA-220R, PA-800 Series, PA-3000 Series, PA-3200 Series, PA-5200 Series, and PA-7000 Series | Palo Alto Networks, Inc. | FIPS 140-2 |  |  |  |
PAN-OS 9.0 VM-Series | Palo Alto Networks, Inc. | FIPS 140-2 |  |  |  |
WildFire 9.0 WF-500 | Palo Alto Networks, Inc. | FIPS 140-2 |  |  |  |
Pavilion Cryptographic Module | Pavilion Data Systems | FIPS 140-2 |  |  |  |
Phison TCG OPAL SSC SSD Series | Phison Electronics Corporation | FIPS 140-2 |  |  |  |
X4i Hardware Security Module (HSM) | Pitney Bowes, Inc. | FIPS 140-2 |  |  |  |
Poly Unified Communications Cryptographic Module | Plantronics, Inc. | FIPS 140-2 |  |  |  |
PreVeil Cryptographic Module | PreVeil, Inc. | FIPS 140-2 |  |  |  |
ENFORCER R1 | Private Machines Inc. | FIPS 140-2 |  |  |  |
CMS-5000 | QSC, LLC | FIPS 140-2 |  |  |  |
Quadient Postal Security Device (PSD) | Quadient Technologies France | FIPS 140-2 |  |  |  |
Qualcomm(R) Crypto Engine Core | Qualcomm Technologies, Inc. | FIPS 140-2 |  |  |  |
Qualcomm(R) Secure Processing Unit (SPU) | Qualcomm Technologies, Inc. | FIPS 140-2 |  |  |  |
Qualcomm(R) Trusted Execution Environment Software Cryptographic Library | Qualcomm Technologies, Inc. | FIPS 140-2 |  |  |  |
Quantum Xchange FIPS Module | Quantum Xchange | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 7 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 7 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 7 OpenSSH Client Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 7 OpenSSH Server Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 7 OpenSSL Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 GnuTLS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 GnuTLS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 libgcrypt Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 OpenSSL Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
Red Hat Enterprise Linux 8 OpenSSL Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 |  |  |  |
RS9113 | Redpine Signals, Inc. | FIPS 140-2 |  |  |  |
SBC 5400 Session Border Controller | Ribbon Communications, Inc. | FIPS 140-2 |  |  |  |
RSA BSAFE(R) Crypto Module | RSA | FIPS 140-2 |  |  |  |
RSA BSAFE(R) Crypto-C Micro Edition | RSA | FIPS 140-2 |  |  |  |
RSA BSAFE(R) Crypto-J JSAFE and JCE Software Module 6.2.5 | RSA Security LLC | FIPS 140-2 |  |  |  |
RSA BSAFE(R) Crypto-J JSAFE and JCE Software Module 6.2.5 | RSA Security LLC | FIPS 140-2 |  |  |  |
R610-F Access Point, R710 Access Point, R720 Access Point, T610 Access Point, T610s Access Point, T710 Access Point, T710s Access Point, E510 Access Point | Ruckus Wireless, Inc. | FIPS 140-2 |  |  |  |
Ruckus Networks Virtual Smart Zone (vSZ) | Ruckus Wireless, Inc. | FIPS 140-2 |  |  |  |
Ruckus Networks Virtual SmartZone - Data Plane (vSZ-D) | Ruckus Wireless, Inc. | FIPS 140-2 |  |  |  |
Virtual SmartZone (vSZ) WLAN Controller | Ruckus Wireless, Inc. | FIPS 140-2 |  |  |  |
Samsung BoringSSL Cryptographic Module | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung Flash Memory Protector V2.0 | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung Kernel Cryptographic Module | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung NVMe TCG Opal SSC SEDs PM1733 Series | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung NVMe TCG Opal SSC SEDs PM983 Series | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung SAS 12G TCG Enterprise SSC SEDs PM1643a/PM1645a Series | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
Samsung SCrypto Cryptographic Module | Samsung Electronics Co., Ltd. | FIPS 140-2 |  |  |  |
CN Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 |  |  |  |
CN6000 Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 |  |  |  |
Silver Peak Unity EdgeConnect EC-XS-FIPS, EC-M-P-FIPS, EC-XL-P-FIPS and EC-XL-P-NM-FIPS | Silver Peak Systems, Inc. | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Kernel Crypto API Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server GnuTLS Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server Kernel Crypto API Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server libgcrypt Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server libgcrypt Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server Libica Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server NSS Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server OpenSSL Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
SUSE Linux Enterprise Server OpenSSL Cryptographic Module | SUSE, LLC | FIPS 140-2 |  |  |  |
Taglio PIV Applet v2.1 on NXP JCOP 3 SecID P60 CS (OSB) | Taglio | FIPS 140-2 |  |  |  |
Thales Luna K7 Cryptographic Module | Thales | FIPS 140-2 |  |  |  |
Vormetric Transparent Encryption Cryptographic Module | Thales | FIPS 140-2 |  |  |  |
Luna T7 Cryptographic Module | Thales Trusted Cyber Technologies | FIPS 140-2 |  |  |  |
TippingPoint Crypto Core OpenSSL | Trend Micro Inc. | FIPS 140-2 |  |  |  |
UD info DA-series FIPS SSD | UD info Corp. | FIPS 140-2 |  |  |  |
Unisys Linux Kernel Cryptographic API Module | Unisys Corporation | FIPS 140-2 |  |  |  |
Unisys Linux strongSwan Cryptographic Module | Unisys Corporation | FIPS 140-2 |  |  |  |
Unisys OpenSSL Linux Cryptographic Module | Unisys Corporation | FIPS 140-2 |  |  |  |
Suite B Cryptographic Module | United States Special Operations Command (USSOCOM) | FIPS 140-2 |  |  |  |
CryptoServer CSe-Series | Utimaco IS GmbH | FIPS 140-2 |  |  |  |
CryptoServer Se-Series Gen2 | Utimaco IS GmbH | FIPS 140-2 |  |  |  |
VaultIP | Verimatrix | FIPS 140-2 |  |  |  |
Vidyo Cryptographic Security Kernel | Vidyo, Inc. | FIPS 140-2 |  |  |  |
VMware’s Linux Cryptographic Module | VMware, Inc. | FIPS 140-2 |  |  |  |
VMware's SD-WAN VPN Crypto Module | VMware, Inc. | FIPS 140-2 |  |  |  |
VMware's SD-WAN VPN Hybrid Crypto Module | VMware, Inc. | FIPS 140-2 |  |  |  |
Vocera Smartbadge Cryptographic Module | Vocera Communications, Inc. | FIPS 140-2 |  |  |  |
WatchGuard Firebox M270[1], M370[2], M470[3], M570[4], M670[5] | WatchGuard Technologies, Inc. | FIPS 140-2 |  |  |  |
WatchGuard Firebox T15[1], T15-W[2], T35[3], T35-W[4], T55[5], T55-W[6], T70[7] | WatchGuard Technologies, Inc. | FIPS 140-2 |  |  |  |
Ultrastar® DC HC330 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 |  |  |  |
Ultrastar® DC SS540 TCG Enterprise SSD | Western Digital Corporation | FIPS 140-2 |  |  |  |
YubiHSM 2 Cryptographic Module (Level 3) | Yubico, Inc. | FIPS 140-2 |  |  |  |
YubiKey 5 Cryptographic Module (Level 1) | Yubico, Inc. | FIPS 140-2 |  |  |  |
YubiKey 5 Cryptographic Module (Level 2) | Yubico, Inc. | FIPS 140-2 |  |  |  |
DHSSL Cryptographic Module | Zhejiang Dahua Technology Co., Ltd. | FIPS 140-2 |  |  |  |
Displayed: 275 | 164 | 46 | 62 | 3
Not Displayed: 26 | 10 | 8 | 7 | 1
Total: 301 | 174 | 54 | 69 | 4

Created October 11, 2016, Updated October 16, 2020